"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var rxjs_1 = require("rxjs");
require("rxjs");
var HttpPresetService = HttpPresetService_1 = (function () {
    function HttpPresetService(http) {
        this.http = http;
        this.token = null;
        this.baseURL = null;
        HttpPresetService_1.me = this;
    }
    /**
     * Perform http get resquest
     *
     * @param {string} url request url. example: http://www.mon-api.net/article ou http://www.mon-api.net/article/1 (dans le cas où l'on souhaite recuppérer un seule élement).
     */
    HttpPresetService.prototype.get = function (url) {
        return new rxjs_1.Observable(function (observer) {
            HttpPresetService_1.me.http.get(url)
                .subscribe(function (data) {
                observer.next(data);
            }, function (error) {
                observer.error(error);
            });
            return { unsuscribe: function () { } };
        });
    };
    /**
     * Perform http post request
     *
     * @param {string} url  request url. example: http://www.mon-api.net/article
     * @param {any}    data json datas.
     */
    HttpPresetService.prototype.post = function (url, data) {
        var _this = this;
        return new rxjs_1.Observable(function (observer) {
            HttpPresetService_1.me.http.post(url, _this.jsonToUrlEncoded(data), HttpPresetService_1.httpOptions)
                .subscribe(function (data) {
                observer.next(data);
            }, function (error) {
                observer.error(error);
            });
            return { unsuscribe: function () { } };
        });
    };
    /**
     * Perform http put request
     *
     * @param {string} url  url request. example: http://www.mon-api.net/article/1
     * @param {any}    data json datas.
     */
    HttpPresetService.prototype.put = function (url, data) {
        var _this = this;
        return new rxjs_1.Observable(function (observer) {
            HttpPresetService_1.me.http.put(url, _this.jsonToUrlEncoded(data), HttpPresetService_1.httpOptions)
                .subscribe(function (data) {
                observer.next(data);
            }, function (error) {
                observer.error(error);
            });
            return { unsuscribe: function () { } };
        });
    };
    /**
     * Perform http delete request
     *
     * @param {string} url request url. example: http://www.mon-api.net/article/1
     */
    HttpPresetService.prototype.delete = function (url) {
        return new rxjs_1.Observable(function (observer) {
            HttpPresetService_1.me.http.delete(url)
                .subscribe(function (data) {
                observer.next(data);
            }, function (error) {
                observer.error(error);
            });
            return { unsuscribe: function () { } };
        });
    };
    /**
     * Define token
     *
     * @param {string} token [description]
     */
    HttpPresetService.prototype.setToken = function (token) {
        this.token = token;
    };
    /**
     * Define base url of api
     *
     * @param {string} url [description]
     */
    HttpPresetService.prototype.setBaseURL = function (url) {
        this.baseURL = url;
    };
    /**
     * Define resource of route api
     * @param {string}            name     name of route
     * @param {string}            method   http method (GET, POST, PUT, DELETE)
     * @param {any = null}        data     json data formated
     * @param {string = null}     id       item id
     * @param {boolean = false}   token    tell if token must be used
     */
    HttpPresetService.prototype.resource = function (name, method, data, id, token) {
        if (data === void 0) { data = null; }
        if (id === void 0) { id = null; }
        if (token === void 0) { token = false; }
        if (method == "get" && id == null) {
            var url = this.baseURL + "/" + name;
            (token) ? (url + '?token=' + this.token) : null;
            return this.get(url);
        }
        if (method == "get" && id != null) {
            var url = this.baseURL + "/" + name + "/" + id;
            (token) ? (url + '?token=' + this.token) : null;
            return this.get(url);
        }
        if (method == "post") {
            var url = this.baseURL + "/" + name;
            (token) ? (url + '?token=' + this.token) : null;
            return this.post(url, data);
        }
        if (method == "put") {
            var url = this.baseURL + "/" + name + "/" + id;
            (token) ? (url + '?token=' + this.token) : null;
            return this.put(url, data);
        }
        if (method == "delete") {
            var url = this.baseURL + "/" + name + "/" + id;
            (token) ? (url + '?token=' + this.token) : null;
            return this.delete(url);
        }
    };
    /**
      * Convert json to x-www-url-encoded
      *
      * @param {any[]} jsonElt [description]
      */
    HttpPresetService.prototype.jsonToUrlEncoded = function (jsonElt) {
        var cp = 0;
        var urlEncoded = '';
        for (var key in jsonElt) {
            if (cp == 0) {
                urlEncoded += key + '=' + jsonElt[key];
            }
            else {
                urlEncoded += '&' + key + '=' + jsonElt[key];
            }
            cp++;
        }
        return urlEncoded;
    };
    return HttpPresetService;
}());
HttpPresetService.httpOptions = {
    headers: new http_1.HttpHeaders({
        'Content-Type': 'application/x-www-form-urlencoded'
    })
};
HttpPresetService = HttpPresetService_1 = __decorate([
    core_1.Injectable(),
    __metadata("design:paramtypes", [typeof (_a = typeof http_1.HttpClient !== "undefined" && http_1.HttpClient) === "function" && _a || Object])
], HttpPresetService);
exports.HttpPresetService = HttpPresetService;
var HttpPresetService_1, _a;
//# sourceMappingURL=http-preset.service.js.map